﻿using System;
using System.Diagnostics;
using System.Runtime.InteropServices.WindowsRuntime;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Media;
using Windows.UI.Xaml.Media.Imaging;
using Windows.UI.Xaml.Navigation;

// The Blank Page item template is documented at http://go.microsoft.com/fwlink/?LinkId=234238

namespace GenerateImage
{
    /// <summary>
    /// An empty page that can be used on its own or navigated to within a Frame.
    /// </summary>
    public sealed partial class MainPage : Page
    {
        public MainPage()
        {
            this.InitializeComponent();
        }

        /// <summary>
        /// Invoked when this page is about to be displayed in a Frame.
        /// </summary>
        /// <param name="e">Event data that describes how this page was reached.  The Parameter
        /// property is typically used to configure the page.</param>
        protected override void OnNavigatedTo(NavigationEventArgs e)
        {
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            var sw = Stopwatch.StartNew();

            var size = Int32.Parse((Size.SelectedItem as ListBoxItem).Content.ToString());
            var image = new WriteableBitmap((int)Image.Width, (int)Image.Height);

            Image.Source = GenerateImage(image, size);

            sw.Stop();
            Output.Text = string.Format("{0} ms", sw.ElapsedMilliseconds);
        }

        private ImageSource GenerateImage(WriteableBitmap bitmap, int size)
        {
            using (var stream = bitmap.PixelBuffer.AsStream())
            {
                for (var i = 0; i < bitmap.PixelWidth * bitmap.PixelHeight; i++)
                {
                    var x = i % bitmap.PixelWidth;
                    var y = i / bitmap.PixelWidth;
                    var value = (x % (size * 2) < size ^ (y % (size * 2) < size)) ? (byte)0 : (byte)255;
                    stream.WriteByte(value); // write a byte for each RGB color
                    stream.WriteByte(value);
                    stream.WriteByte(255);
                    stream.WriteByte(0); // alpha channel
                }
            }

            return bitmap;
        }

        private ImageSource GenerateImageOptimized(WriteableBitmap bitmap, int size)
        {
            using (var stream = bitmap.PixelBuffer.AsStream())
            {
                var width = bitmap.PixelWidth; // Cross boundary calls
                var height = bitmap.PixelHeight; // moved out of the loop
                for (var i = 0; i < width * height; i++)
                {
                    var x = i % width;
                    var y = i / width;
                    var value = (x % (size * 2) < size ^ (y % (size * 2) < size)) ? (byte)0 : (byte)255;
                    stream.WriteByte(value); // write a byte for each RGB color
                    stream.WriteByte(value);
                    stream.WriteByte(255);
                    stream.WriteByte(0); // alpha channel
                }
            }
            return bitmap;
        }
    }
}
