﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Runtime.InteropServices.WindowsRuntime;
using Windows.Foundation;
using Windows.Foundation.Collections;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Controls.Primitives;
using Windows.UI.Xaml.Data;
using Windows.UI.Xaml.Input;
using Windows.UI.Xaml.Media;
using Windows.UI.Xaml.Navigation;
using Windows.UI.Xaml.Shapes;

// The Blank Page item template is documented at http://go.microsoft.com/fwlink/?LinkId=234238

namespace GridVirtualization
{
    /// <summary>
    /// An empty page that can be used on its own or navigated to within a Frame.
    /// </summary>
    public sealed partial class MainPage : Page
    {
        private ViewModel vm = new ViewModel();

        public MainPage()
        {
            this.InitializeComponent();
            vm.GetImages();
            vm.GroupImages();
            DataContext = vm.GroupedImages;
        }


        private void ContainerContentChanging(ListViewBase sender, ContainerContentChangingEventArgs args)
        {
            // for improved performance, set Handled to true so the app does not set content on this item
            args.Handled = true;

            var templateRoot = (Border)args.ItemContainer.ContentTemplateRoot;
            var textBg = (Rectangle)templateRoot.FindName("textBackground");
            var title = (TextBlock)templateRoot.FindName("titleText");
            var desc = (TextBlock)templateRoot.FindName("descText");
            var dropShadow = (Rectangle)templateRoot.FindName("dropShadow");
            var image = (Image)templateRoot.FindName("picture");

            textBg.Opacity = 0;
            title.Opacity = 0;
            desc.Opacity = 0;
            dropShadow.Opacity = 0;
            image.Opacity = 0;

            args.RegisterUpdateCallback(ShowText);
        }

        private void ShowText(ListViewBase sender, ContainerContentChangingEventArgs args)
        {
            var picture = (AbstractPicture)args.Item;
            var templateRoot = (Border)args.ItemContainer.ContentTemplateRoot;

            var textBg = (Rectangle)templateRoot.FindName("textBackground");
            var title = (TextBlock)templateRoot.FindName("titleText");
            var desc = (TextBlock)templateRoot.FindName("descText");

            title.Text = picture.Title;
            desc.Text = picture.Description;

            textBg.Opacity = 1;
            title.Opacity = 1;
            desc.Opacity = 1;

            args.RegisterUpdateCallback(ShowPicture);
        }

        private void ShowPicture(ListViewBase sender, ContainerContentChangingEventArgs args)
        {
            var picture = (AbstractPicture)args.Item;
            var templateRoot = (Border)args.ItemContainer.ContentTemplateRoot;

            var dropShadow = (Rectangle)templateRoot.FindName("dropShadow");
            var image = (Image)templateRoot.FindName("picture");

            image.Source = picture.Location;

            dropShadow.Opacity = 1;
            image.Opacity = 1;
        }
    }
}
