﻿using System;
using System.Diagnostics;
using System.Diagnostics.Tracing;
using System.Runtime.InteropServices.WindowsRuntime;
using Windows.Foundation.Diagnostics;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Media;
using Windows.UI.Xaml.Media.Imaging;
using Windows.UI.Xaml.Navigation;

// The Blank Page item template is documented at http://go.microsoft.com/fwlink/?LinkId=234238

namespace GenerateImage
{
    /// <summary>
    /// An empty page that can be used on its own or navigated to within a Frame.
    /// </summary>
    public sealed partial class MainPage : Page
    {
        public MainPage()
        {
            this.InitializeComponent();
        }

        /// <summary>
        /// Invoked when this page is about to be displayed in a Frame.
        /// </summary>
        /// <param name="e">Event data that describes how this page was reached.  The Parameter
        /// property is typically used to configure the page.</param>
        protected override void OnNavigatedTo(NavigationEventArgs e)
        {
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            var sw = Stopwatch.StartNew();

            using (var channel = new LoggingChannel("Generate Image"))
            {
                int width, height, size;

                using (var setup = new LoggingActivity("Setup", channel))
                {
                    width = (int)Image.Width;
                    height = (int)Image.Height;
                    size = Int32.Parse((Size.SelectedItem as ListBoxItem).Content.ToString());
                }

                using (var creation = new LoggingActivity("Image Creation", channel))
                {
                    Image.Source = GenerateImage(width, height, size);
                }
            }

            sw.Stop();
            Output.Text = sw.ElapsedMilliseconds.ToString();
        }


        private ImageSource GenerateImage(int width, int height, int size)
        {
            var bitmap = new WriteableBitmap(width, height);

            using (var stream = bitmap.PixelBuffer.AsStream())
            {
                var a = new byte[width * height * 4];
                for (int i = 0; i < a.Length; i += 4)
                {
                    var x = i / 4 % width;
                    var y = i / 4 / width;

                    var value = (x % (size * 2) < size ^ (y % (size * 2) < size)) ? (byte)0 : (byte)255;
                    a[i] = value;
                    a[i + 1] = value;
                    a[i + 2] = 255;
                    a[i + 3] = 0;
                }

                stream.Write(a, 0, a.Length);
            }

            return bitmap;
        }
    }
}
