using System;
using System.Diagnostics.Tracing;

namespace GenerateImage
{
    [EventSource(Name = "AppPerformanceBook-Samples-CustomEventSource")]
    public sealed class CustomEventSource : EventSource
    {
        private static readonly CustomEventSource Log = new CustomEventSource();

        // Information about specific tasks
        public class Tasks
        {
            public const EventTask GenerateImage = (EventTask)1;
            // Add additional tasks as needed
        }

        // Start message for the specific task of creating an image
        [Event(1, Opcode = EventOpcode.Start, Task = Tasks.GenerateImage)]
        public void Begin(string text, int width, int height, int size)
        {
            WriteEvent(1, text, width, height, size);
        }
        
        [Event(2, Opcode = EventOpcode.Stop, Task = Tasks.GenerateImage)]
        public void End()
        {
            WriteEvent(2);
        }

        [NonEvent]
        public static IDisposable MeasureGenerateImage(string text, int width, int height, int size)
        {
            return new Logger(text, width, height, size);
        }

        /// <summary>
        /// Wraps Begin/End as IDisposable
        /// </summary>
        public class Logger : IDisposable
        {
            public Logger(string text, int width, int height, int size)
            {
                Log.Begin(text, width, height, size);
            }
            public void Dispose()
            {
                Log.End();
            }
        }
    }
}