﻿using System;
using System.Collections.Generic;
using System.Linq;
using Diagnostics.Tracing;
using Diagnostics.Tracing.Parsers;

namespace TestReport
{
    class Program
    {
        private static string ProviderName = "Microsoft-Windows-Diagnostics-LoggingChannel";
        private static string ProcessName = "GenerateImage";
        private static string ChannelKey = "LoggingChannelName";
        private static string ChannelName = "Generate Image";
        private static string ActivityKey = "ActivityName";
        private static string ActivityName = "Image Creation";

        private static int GoalInMs = 50;

        static int Main(string[] args)
        {
            var file = args.FirstOrDefault();

            if (string.IsNullOrEmpty(file))
            {
                Console.WriteLine("Syntax: TestReport <ETL file>");
                return -1;
            }

            Console.WriteLine("Processing measurements from {0}", file);

            using (var source = new ETWTraceEventSource(file))
            {
                // The RegisteredTraceEventParser is useful for parsing registered system events
                var parser = new RegisteredTraceEventParser(source);

                var starttime = DateTime.MinValue;

                // Attach an event that fires for each event
                parser.All += delegate(TraceEvent data)
                {
                    // Filter to only handle relevant events
                    if (data.ProviderName == ProviderName &&
                        data.ProcessName == ProcessName &&
                        (string)data.PayloadByName(ChannelKey) == ChannelName &&
                        (string)data.PayloadByName(ActivityKey) == ActivityName)
                    {
                        if (data.Opcode == TraceEventOpcode.Start)
                        {
                            starttime = data.TimeStamp;
                        }

                        // Start and stop events come in pairs - to handle nested events use a stack
                        if (data.Opcode == TraceEventOpcode.Stop)
                        {
                            var duration = (data.TimeStamp - starttime).Milliseconds;
                            Console.WriteLine("Image creation took {0} ms. Test {1}", duration, duration > GoalInMs ? "failed" : "passed");
                        }
                    }
                };

                // Start processing of the source and fire events
                source.Process();
            }

            return 0;
        }
    }
}
